# Confined aquifer slug test example

<!-- Please write anything you'd like to explain about the forward problem here -->

This Inversion Test Problem demonstrates two solutions for the 
time-displacement response at a groundwater well resulting from the application 
of a single well falling head slug test. Both solutions describe the response 
for a fully confined aquifer. These are:

1. Cooper-Bredehoeft-Papadopulos (1967) solution

2. Hvorslev (1951) solution

These solutions assume full aquifer penetration by the tested well. All 
solutions are calculated in the Laplace domain and are inverted to the time 
domain numerically using the De Hoog et al. (1982) algorithm.
